@@ -123,18 +123,20 @@ rdbwselect = function(y, x, c = NULL, fuzzy = NULL, deriv = NULL, p = NULL, q =
     mass_l = 1-M_l/N_l
     mass_r = 1-M_r/N_r				
     if (mass_l>=0.1 | mass_r>=0.1){
-      print("Mass points detected in the running variable.")
-      if (masspoints=="check") print("Try using option masspoints=adjust.")
+      warning("Mass points detected in the running variable.")
+      if (masspoints=="check") warning("Try using option masspoints=adjust.")
       if (is.null(bwcheck) & masspoints=="adjust") bwcheck <- 10
     }				
   }
   
-  covs_drop_coll=dZ=0
-  if (covs_drop == TRUE) covs_drop_coll = 1 
-    
+
 
   ############## COLLINEARITY
-  if (!is.null(covs)) {
+  covs_drop_coll=dZ=0
+  if (!is.null(covs)) dZ = ncol(covs)
+  if (covs_drop == TRUE) covs_drop_coll = 1 
+  
+  if (!is.null(covs) & isTRUE(covs_drop)) {
     covs.names = colnames(covs)
     if (is.null(covs.names)) {
       covs.names = paste("z",1:ncol(covs),sep="")
@@ -144,67 +146,64 @@ rdbwselect = function(y, x, c = NULL, fuzzy = NULL, deriv = NULL, p = NULL, q =
     covs = as.matrix(covs)
     dZ = length(covs.names)
     covs.check = covs_drop_fun(covs)
-    if (covs.check$ncovs < dZ & covs_drop==FALSE) {
-      print("Multicollinearity issue detected in covs. Please rescale and/or remove redundant covariates, or use covs_drop option.")  
-    }
-    if (covs.check$ncovs < dZ & isTRUE(covs_drop)) {
+    if (covs.check$ncovs < dZ) {
       covs  <- as.matrix(covs.check$covs)
       dZ    <- covs.check$ncovs
-      #print("Multicollinearity issue detected in covs. Redundant covariates dropped.")  
+      warning("Multicollinearity issue detected in covs. Redundant covariates dropped.")  
     }
   }
   
     exit=0
     #################  ERRORS
     if (kernel!="uni" & kernel!="uniform" & kernel!="tri" & kernel!="triangular" & kernel!="epa" & kernel!="epanechnikov" & kernel!="" ){
-      print("kernel incorrectly specified")
+      warning("kernel incorrectly specified")
       exit = 1
     }
     
     if  (bwselect!="mserd" & bwselect!="msetwo" & bwselect!="msesum" & bwselect!="msecomb1" & bwselect!="msecomb2"  & bwselect!="cerrd" & bwselect!="certwo" & bwselect!="cersum" & bwselect!="cercomb1" & bwselect!="cercomb2" & bwselect!=""){
-      print("bwselect incorrectly specified")  
+      warning("bwselect incorrectly specified")  
       exit = 1
     }
     
     if (bwselect=="CCT" | bwselect=="IK" | bwselect=="CV" | bwselect=="cct" | bwselect=="ik" | bwselect=="cv"){
-      print("bwselect options IK, CCT and CV have been depricated. Please see help for new options")  
+      warning("bwselect options IK, CCT and CV have been depricated. Please see help for new options")  
       exit = 1
     }
     
     if (vce!="nn" & vce!="" & vce!="hc1" & vce!="hc2" & vce!="hc3" & vce!="hc0"){ 
-      print("vce incorrectly specified")
+      warning("vce incorrectly specified")
       exit = 1
     }
 
     if (c<=x_min | c>=x_max){
-      print("c should be set within the range of x")
+      warning("c should be set within the range of x")
       exit = 1
     }
     
     if (p<0 | q<0 | deriv<0 | nnmatch<=0 ){
-      print("p, q, deriv and matches should be positive integers")
+      warning("p, q, deriv and matches should be positive integers")
       exit = 1
     }
     
     if (p>=q){
-      print("q should be set higher than p")
+      warning("q should be set higher than p")
       exit = 1
     }
     
     if (deriv>p){
-      print("deriv can only be equal or lower p")
+      warning("deriv can only be equal or lower p")
       exit = 1
     }
     
     p_round = round(p)/p;    q_round = round(q)/q;    d_round = round(deriv+1)/(deriv+1);    m_round = round(nnmatch)/nnmatch
         
     if ((p_round!=1 &p>0) | (q_round!=1&q>0) | d_round!=1 | m_round!=1 ){
-      print("p,q,deriv and matches should be integer numbers")
+      warning("p,q,deriv and matches should be integer numbers")
       exit = 1
     }
     
     if (N<20){
-      print("Not enough observations to perform bandwidth calculations")
+      warning("Not enough observations to perform bandwidth calculations")
       exit = 1
     }
     
@@ -426,7 +425,7 @@ cer_b = 1
 		b_cercomb2_r = b_msecomb2_r*cer_b
 	}
 
-if (all=="FALSE"){
+if (all==FALSE){
   bw_list = bwselect
   bws = matrix(NA,1,4)
   colnames(bws)=c("h (left)","h (right)","b (left)","b (right)")
