@@ -90,7 +90,9 @@ rdrobust = function(y, x, c = NULL, fuzzy = NULL, deriv = NULL,
   ############## COLLINEARITY
   covs_drop_coll=dZ=0
   if (covs_drop == TRUE) covs_drop_coll = 1 
-  if (!is.null(covs)) {
+  if (!is.null(covs)) dZ = ncol(covs)
+  
+  if (!is.null(covs) & isTRUE(covs_drop)) {
     covs.names = colnames(covs)
     if (is.null(covs.names)) {
       covs.names = paste("z",1:ncol(covs),sep="")
@@ -100,12 +102,10 @@ rdrobust = function(y, x, c = NULL, fuzzy = NULL, deriv = NULL,
     covs = as.matrix(covs)
     dZ = length(covs.names)
     covs.check = covs_drop_fun(covs)
-    if (covs.check$ncovs < dZ & covs_drop==FALSE) {
-      print("Multicollinearity issue detected in covs. Please rescale and/or remove redundant covariates, or use covs_drop option.")  
-    }
-    if (covs.check$ncovs < dZ & isTRUE(covs_drop)) {
+    if (covs.check$ncovs < dZ) {
       covs  <- as.matrix(covs.check$covs)
       dZ    <- covs.check$ncovs
+      warning("Multicollinearity issue detected in covs. Redundant covariates dropped.")  
     }
   }
   
@@ -191,38 +191,38 @@ rdrobust = function(y, x, c = NULL, fuzzy = NULL, deriv = NULL,
   #####################################################   CHECK ERRORS
   exit=0
   if (kernel!="uni" & kernel!="uniform" & kernel!="tri" & kernel!="triangular" & kernel!="epa" & kernel!="epanechnikov" & kernel!="" ){
-    print("kernel incorrectly specified")
+    warning("kernel incorrectly specified")
     exit = 1
   }
   
   if  (bwselect!="mserd" & bwselect!="msetwo" & bwselect!="msesum" & bwselect!="msecomb1" & bwselect!="msecomb2" & bwselect!="cerrd" & bwselect!="certwo" & bwselect!="cersum" & bwselect!="cercomb1" & bwselect!="cercomb2" & bwselect!=""){
-    print("bwselect incorrectly specified")  
+    warning("bwselect incorrectly specified")  
     exit = 1
   }
   
   if (bwselect=="cct" | bwselect=="ik" | bwselect=="cv"){
-    print("bwselect options IK, CCT and CV have been depricated. Please see help for new options")  
+    warning("bwselect options IK, CCT and CV have been depricated. Please see help for new options")  
     exit = 1
   }
   
   if (vce!="nn" & vce!="" & vce!="hc1" & vce!="hc2" & vce!="hc3" & vce!="hc0"){ 
-    print("vce incorrectly specified")
+    warning("vce incorrectly specified")
     exit = 1
   }
     
   if (c<=x_min | c>=x_max){
-    print("c should be set within the range of x")
+    warning("c should be set within the range of x")
     exit = 1
   }
     
   if (level>100 | level<=0){
-    print("level should be set between 0 and 100")
+    warning("level should be set between 0 and 100")
     exit = 1
   }
     
   if (!is.null(rho)){  
      if (rho<0){
-        print("rho should be greater than 0")
+        warning("rho should be greater than 0")
         exit = 1
       }
   }
@@ -237,7 +237,7 @@ rdrobust = function(y, x, c = NULL, fuzzy = NULL, deriv = NULL,
     
   
   if (N<20){
-			print("Not enough observations to perform bandwidth calculations. Estimates computed using entire sample")
+			warning("Not enough observations to perform bandwidth calculations. Estimates computed using entire sample")
       h = b = max(range_l,range_r)
 			bwselect = "Manual"
 		}
@@ -279,8 +279,8 @@ rdrobust = function(y, x, c = NULL, fuzzy = NULL, deriv = NULL,
       mass_l = 1-M_l/N_l
       mass_r = 1-M_r/N_r				
       if (mass_l>=0.1 | mass_r>=0.1){
-        print("Mass points detected in the running variable.")
-        if (masspoints=="check") print("Try using option masspoints=adjust.")
+        warning("Mass points detected in the running variable.")
+        if (masspoints=="check") warning("Try using option masspoints=adjust.")
         if (is.null(bwcheck) & masspoints=="adjust") bwcheck <- 10
       }				
     }
